@@ -35,6 +35,18 @@ query jobsQuery($projectId: UUID!, $category: String, $technologyId: UUID, $inst
             releaseNote
             runtimeVersion
             commandLine
+            packageInfo{
+                name
+                downloadUrl
+            }
+            dockerInfo{
+                image
+                dockerCredentialsId
+            }
+            extraTechnology{
+                language
+                version
+            }
             isCurrent
             isMajor
         }
@@ -57,6 +69,7 @@ query jobsQuery($projectId: UUID!, $category: String, $technologyId: UUID, $inst
         graphPipelines{
             id
         }
+        doesUseGPU
         resources{
             cpu {
                 request
@@ -75,16 +88,18 @@ GQL_GET_JOB_INSTANCE = """
 query jobInstanceQuery($jobInstanceId: UUID!){
     jobInstance(id: $jobInstanceId){
       id
+      number
       status
       startTime
       endTime
+      jobId
       version {
         number
         releaseNote
         runtimeVersion
         commandLine
         isMajor
-        doesUseGPU
+        isCurrent
       }
     }
   }
@@ -211,7 +226,7 @@ mutation addJobVersionMutation($jobId: UUID!, $releaseNote: String, $runtimeVers
 """
 
 GQL_GET_JOB_INFO = """
-query jobInfoQuery($jobId: UUID!, $instancesLimit: Int){
+query jobInfoQuery($jobId: UUID!, $instancesLimit: Int, $versionsLimit: Int, $versionsOnlyCurrent: Boolean){
     job(id: $jobId){
         id
         name
@@ -239,10 +254,25 @@ query jobInfoQuery($jobId: UUID!, $instancesLimit: Int){
             }
         }
         countJobInstance
-        versions {
+        versions(limit: $versionsLimit, onlyCurrent: $versionsOnlyCurrent) {
+            number
+            creationDate
             releaseNote
             runtimeVersion
             commandLine
+            packageInfo{
+                name
+                downloadUrl
+            }
+            dockerInfo{
+                image
+                dockerCredentialsId
+            }
+            extraTechnology{
+                language
+                version
+            }
+            isCurrent
             isMajor
         }
         category
@@ -261,6 +291,7 @@ query jobInfoQuery($jobId: UUID!, $instancesLimit: Int){
         graphPipelines(isCurrent: true){
             id
         }
+        doesUseGPU
         resources{
             cpu {
                 request
